@@ -99,7 +99,8 @@ class RPCClient(object):
         """Return accounts_pending for accounts"""
         pending_action = {
             'action': 'accounts_pending',
-            'accounts': accounts
+            'accounts': accounts,
+            'include_only_confirmed': True
         }
         return await self.make_request(pending_action)
 
@@ -108,13 +109,20 @@ class RPCClient(object):
         pending_action = {
             'action': 'pending',
             'account': account,
-            'threshold': str(threshold)
+            'threshold': str(threshold),
+            'include_only_confirmed': True
         }
         resp = await self.make_request(pending_action)
         ret = []
         if 'blocks' in resp:
             if resp['blocks'] == '':
                 return []
+            # Response format changes when threshold is <= 0
+            # blocks: ['ABC...', 'ABC...']
+            if threshold <= 0:
+                return resp['blocks']
+            # When threshold is > 0
+            # blocks: {'ABC..', '10000', 'ABC..': '2000'}             
             for k,v in resp['blocks'].items():
                 ret.append(k)
             return ret
